===============================
deadgargoyle
===============================

.. .. image:: https://img.shields.io/travis/pydanny/deadgargoyle.svg
..         :target: https://travis-ci.org/pydanny/deadgargoyle

.. image:: https://img.shields.io/pypi/v/deadgargoyle.svg
        :target: https://pypi.python.org/pypi/deadgargoyle


Identifies Gargoyle switches that are no longer necessary

* Free software: Apache2
* Documentation: https://deadgargoyle.readthedocs.org.

Features
--------

* Search through Gargoyle switches configuring in Django `settings` modules.
* TODO: Reports Gargoyle switch record orphans.

Thanks
------

Bartek Ogryczak (@vartec) for giving me the inspiration.
